#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-ormolu-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-ormolu-plugin-2.3.0.0-AmfzSOhkkbvElIwi0ire0D
key:                  hls-ormolu-plugin-2.3.0.0-AmfzSOhkkbvElIwi0ire0D
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  bf9e7b5cdbd1b261624d03468d1edd12
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-2.3.0.0-AmfzSOhkkbvElIwi0ire0D
depends:
    base-4.18.2.1 extra-1.7.16-92gEBqN3yIpF5We3DBC4D filepath-1.4.300.1
    ghc-9.6.6 ghc-boot-th-9.6.6 ghcide-2.3.0.0-8SkP0wVOFBS2w32JlGgsVh
    hls-plugin-api-2.3.0.0-EK0DZxCvJ0eCT1uslRvQ79
    lens-5.3.4-FoS34BQg8yPHQoAczDydbc
    lsp-2.2.0.0-9lJlGvT5rLo8cal3T7PXHz mtl-2.3.1
    ormolu-0.7.0.0-HQQlQvkuHOA6YiRoaNPpyr
    process-extras-0.7.4-1tN0mbS8eQp4iPCg4QLmuy text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

